@@ -1,19 +1,17 @@
 import sys
 
-from raven import Client
-
 from scrapy import log
 from scrapy.conf import settings
 
-SENTRY_DSN = None #defaults to os.environ["SENTRY_DSN"]
+from utils import get_client
 
 class SentryMiddleware(object):
     def __init__(self, dsn=None):
-        self.client = Client(dsn)
+        self.client = get_client(dsn)
 
     @classmethod
     def from_settings(cls, settings):
-        dsn = settings.get("SENTRY_DSN", SENTRY_DSN)
+        dsn = settings.get("SENTRY_DSN", None)
         return cls(dsn)
 
     @classmethod
@@ -21,19 +19,19 @@ class SentryMiddleware(object):
         return cls.from_settings(crawler.settings)
 
     def trigger(self, exception, spider=None, extra={}):
-        msg = self.client.captureException(sys.exc_info(), extra=extra)
+        msg = self.client.captureException(exc_info=sys.exc_info(), extra=extra)
         ident = self.client.get_ident(msg)
         
         log.msg("Follow last exception in Sentry '%s'" % ident, 
-            level=log.INFO, spider=spider)
+                level=log.INFO, spider=spider)
 
         return None
         
     def process_exception(self, request, exception, spider):
         return self.trigger(exception, spider, 
-            extra={"spider":spider, "request":request})
+                            extra={"spider":spider, "request":request})
 
     def process_spider_exception(self, response, exception, spider):
         return self.trigger(exception, spider, 
-            extra={"spider":spider, "response":response})
+                            extra={"spider":spider, "response":response})
 
